<?xml version="1.0" encoding="windows-1250"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:UML="org.omg/UML1.3"
	xmlns:xalan="http://xml.apache.org/xalan"
    exclude-result-prefixes="xalan"
	version="1.0">

<xsl:output indent="yes" method="xml" encoding="utf-8"/>
<xsl:param name="multiplier" select="4"/>
<xsl:param name="maxwidth" select="300"/>
<xsl:param name="maxheight" select="800"/>

<xsl:template match="XMI.content">
    <xsl:copy>
        <xsl:apply-templates select="@*|node()" mode="no-tags"/>
        <xsl:apply-templates select="@*|node()" mode="tags"/>
    </xsl:copy>
</xsl:template>
<xsl:template match="@*|node()">
  <xsl:copy>
    <xsl:apply-templates select="@*|node()"/>
  </xsl:copy>
</xsl:template>


<!-- vypusti tagged values v hlavni casti -->
<xsl:template match="UML:ModelElement.taggedValue" mode="no-tags">
</xsl:template>

<!-- predelej generalizace -->
<xsl:template match="UML:GeneralizableElement.generalization" mode="no-tags">
	<UML:Namespace.ownedElement>
		<xsl:variable name="gen" select="//UML:Generalization[@xmi.id = current()/UML:Generalization/@xmi.idref]"/>
	    <xsl:apply-templates select="$gen" mode="generalization"/>
    </UML:Namespace.ownedElement>
</xsl:template>
<xsl:template match="UML:Generalization" mode="no-tags"/>
<xsl:template match="UML:Generalization" mode="generalization">
   <xsl:copy>
    	<xsl:apply-templates select="@*"/>
         <UML:Generalization.child>
          <Foundation.Core.GeneralizableElement xmi.idref = '{UML:Generalization.child/*/@xmi.idref}'/>
         </UML:Generalization.child>
         <UML:Generalization.parent>
          <Foundation.Core.GeneralizableElement xmi.idref = '{UML:Generalization.parent/*/@xmi.idref}'/>
         </UML:Generalization.parent>
   </xsl:copy>
</xsl:template>
<xsl:template match="UML:PresentationElement.subject" mode="no-tags">
     <UML:PresentationElement.subject>
	  <xsl:apply-templates select="*" mode="diag-element"/>
     </UML:PresentationElement.subject>
</xsl:template>
<xsl:template match="*" mode="diag-element">
      <Foundation.Core.ModelElement xmi.idref = '{@xmi.idref}'/>    <!--Class Dite-->
</xsl:template>

<!-- pokud nema role jmeno, pak nema cenu multiplicity -->
<xsl:template match="UML:Multiplicity" mode="no-tags">
		<xsl:copy>
			<xsl:if test="../@name">
    			<xsl:apply-templates select="@*|node()" mode="no-tags"/>
			</xsl:if>
		</xsl:copy>
</xsl:template>


<xsl:template match="UML:MultiplicityRange" mode="no-tags">
	<xsl:copy>
	    <xsl:attribute name="lower"><xsl:value-of select="@lower"/></xsl:attribute>
	    <xsl:attribute name="upper">
			<xsl:choose>
				<xsl:when test="@upper = 'unlimited'">-1</xsl:when>
				<xsl:otherwise><xsl:value-of select="@upper"/></xsl:otherwise>
			</xsl:choose>
	    </xsl:attribute>
	</xsl:copy>
</xsl:template>

<xsl:template match="UML:Association" mode="no-tags">
	<xsl:copy>
		<xsl:attribute name="isSpecification">false</xsl:attribute>
		<xsl:attribute name="isAbstract">false</xsl:attribute>
		<xsl:attribute name="visibility">private</xsl:attribute>
    	<xsl:apply-templates select="@*|node()" mode="no-tags"/>
	</xsl:copy>
</xsl:template>

<xsl:template match="UML:AssociationEnd" mode="no-tags">
	<xsl:copy>
		<xsl:attribute name="changeability"><xsl:value-of select="UML:AssociationEnd.changeability/@xmi.value"/></xsl:attribute>
		<xsl:attribute name="targetScope">instance</xsl:attribute>
		<xsl:attribute name="isSpecification">false</xsl:attribute>
		<xsl:attribute name="isNavigable">false</xsl:attribute>
    	<xsl:apply-templates select="@*|node()" mode="no-tags"/>
	</xsl:copy>
</xsl:template>
<xsl:template match="UML:AssociationEnd.changeability" mode="no-tags">
</xsl:template>

<!-- Musim udelat nasledujici:
- Pro role udelat atributy ve forme
       <UML:AssociationEnd.qualifier>
        <UML:Attribute xmi.idref = 'S.10'/> - typ te druhe strany
       </UML:AssociationEnd.qualifier>
	   
- tento atribut musi byt pridan do dane tridy ve forme
      <UML:Attribute xmi.id = 'S.10'
            name = 'polozky' visibility = 'private' isSpecification = 'false'
            changeability = 'changeable' ownerScope = 'instance'>
       <UML:StructuralFeature.multiplicity>
        <UML:Multiplicity>
         <UML:Multiplicity.range>
          <UML:MultiplicityRange lower = '1' upper = '1'/>
         </UML:Multiplicity.range>
        </UML:Multiplicity>
       </UML:StructuralFeature.multiplicity>
       <UML:StructuralFeature.type>
        <Foundation.Core.Classifier xmi.idref = 'G.6'/>
       </UML:StructuralFeature.type>
      </UML:Attribute>

- k tomuto atributu musi byt tagged value ve forme
  <UML:TaggedValue xmi.id = 'XX.10'
        tag = 'associates' value = '&lt;{Polozka}&gt;'>
   <UML:TaggedValue.modelElement>
    <Foundation.Core.ModelElement xmi.idref = 'S.10'/>
   </UML:TaggedValue.modelElement>
  </UML:TaggedValue>


-->

<!--
<xsl:template match="UML:AssociationEnd.type" mode="no-tags">
    <UML:AssociationEnd.type>
		<xsl:variable name="connection">
			<xsl:choose>
				<xsl:when test="../following-sibling::UML:AssociationEnd">
					<xsl:value-of select="../following-sibling::UML:AssociationEnd/UML:AssociationEnd.type/*/@xmi.idref"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="../preceding-sibling::UML:AssociationEnd/UML:AssociationEnd.type/*/@xmi.idref"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<Foundation.Core.Classifier xmi.idref = '{$connection}'/>
    </UML:AssociationEnd.type>
</xsl:template>
-->


<xsl:template match="UML:Diagram.owner" mode="no-tags">
   <UML:Diagram.owner>
    <Foundation.Core.ModelElement xmi.idref = '{*/@xmi.idref}'/>
   </UML:Diagram.owner>
</xsl:template>

<!-- Prepocet hodnot pozic prvku na diagramu -->
<xsl:template match="UML:DiagramElement/@geometry" mode="no-tags">
	<xsl:variable name="isClass" select="../UML:PresentationElement.subject/UML:Class"/>
	<xsl:attribute name="geometry">
		<xsl:for-each select="xalan:tokenize(., ',')">
			<xsl:choose>
				<xsl:when test="$isClass and position()=3">
					<xsl:choose>
						<xsl:when test=".* $multiplier &gt; $maxwidth">
							<xsl:value-of select="$maxwidth"/><xsl:text>, </xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select=".* $multiplier"/><xsl:text>, </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="$isClass and position()=4">
					<xsl:choose>
						<xsl:when test=".* $multiplier &gt; $maxheight">
							<xsl:value-of select="$maxheight"/><xsl:text>, </xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select=".* $multiplier"/><xsl:text>, </xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select=".* $multiplier"/><xsl:text>, </xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:attribute>
</xsl:template>

<!-- zkopiruj hlavni cast -->
<xsl:template match="@*|node()" mode="no-tags">
  <xsl:copy>
    <xsl:apply-templates select="@*|node()" mode="no-tags"/>
  </xsl:copy>
</xsl:template>

<!-- kopiruj tagged value -->
<xsl:template match="UML:ModelElement.taggedValue" mode="tags">
   <xsl:apply-templates select="UML:TaggedValue" mode="tags"/>
</xsl:template>

<!-- vytvor tagged value pro TCC -->
<xsl:template match="UML:TaggedValue" mode="tags">
  <UML:TaggedValue xmi.id = '{generate-id()}'
        tag = '{@tag}' value = '{@value|UML:TaggedValue.value}'>
   <UML:TaggedValue.modelElement>
    <Foundation.Core.ModelElement xmi.idref = '{../../@xmi.id}'/>
   </UML:TaggedValue.modelElement>
  </UML:TaggedValue>
</xsl:template>

<!-- projizdej hlavni model a kopiruj tagged value -->
<xsl:template match="@*|node()" mode="tags">
    <xsl:apply-templates select="@*|node()" mode="tags"/>
</xsl:template>


</xsl:stylesheet>

